"""
The MIT License (MIT)

Copyright (c) 2015 bpyamasinn.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""

from django.views import View
from django.http import HttpResponse, Http404

from django.core.exceptions import PermissionDenied as _PermissionDenied


class OK(View):
    def get(self, *args, **kwargs):
        return HttpResponse("I'm OK", status=200)


class PermissionDenied(View):
    def get(self, *args, **kwargs):
        raise _PermissionDenied("It is Error with a malicious! (403 Forbidden)")


class NotFound(View):
    def get(self, *args, **kwargs):
        raise Http404("It is Error with a malicious! (404 Not Found)")


class InternalServerError(View):
    def get(self, *args, **kwargs):
        raise ValueError("It is Error with a malicious! (500 Internal Server Error)")



from setuptools import setup


setup(
    name='django-malice',
    author = "salexkidd",
    author_email = "salexkidd@gmail.com",
    url = "https://github.com/salexkidd/django_malice/",
    description='A simple Django app that enables own occuring error.',
    keywords = ["django", "testing",],
    version='0.1.3',
    packages=['malice'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
